# simple

Source: [simple.k](https://url/to/source_code/simple.k)

模块文档，当前模块中定义了一个名为 "Person" 的模型

## Schema Person

Person 是一个简单的模型示例

### Attributes

|Name and Description|Type|Default Value|Required|
|--------------------|----|-------------|--------|
|**name**<br />普通属性，名为 "name"，表示人的名称|str|"Default"|**required**|
|**age**<br />普通属性，名为 "age"，表示人的年龄|int|18|optional|
### Examples
```python
person = Person {
    name: "Alice"
    age: 18
}
```

<!-- Auto generated by kcl-doc tool, please do not edit. -->
